@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1995, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -32,6 +32,7 @@ import java.awt.event.WindowEvent;
 import java.awt.peer.DialogPeer;
 import java.io.IOException;
 import java.io.ObjectInputStream;
+import java.io.Serial;
 import java.security.AccessControlException;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
@@ -300,7 +301,7 @@ public class Dialog extends Window {
      * @see #hideAndDisposeHandler()
      * @see #shouldBlock()
      */
-    transient volatile boolean isInHide = false;
+    transient volatile boolean isInHide;
 
     /*
      * Indicates that this dialog is being disposed. This flag is set to true at
@@ -311,14 +312,15 @@ public class Dialog extends Window {
      * @see #hideAndDisposeHandler()
      * @see #doDispose()
      */
-    transient volatile boolean isInDispose = false;
+    transient volatile boolean isInDispose;
 
     private static final String base = "dialog";
     private static int nameCounter = 0;
 
-    /*
-     * JDK 1.1 serialVersionUID
+    /**
+     * Use serialVersionUID from JDK 1.1 for interoperability.
      */
+    @Serial
     private static final long serialVersionUID = 5920926903803293709L;
 
     /**
@@ -1056,9 +1058,7 @@ public class Dialog extends Window {
                     // if this dialog is toolkit-modal, the filter should be added
                     // to all EDTs (for all AppContexts)
                     if (modalityType == ModalityType.TOOLKIT_MODAL) {
-                        Iterator<AppContext> it = AppContext.getAppContexts().iterator();
-                        while (it.hasNext()) {
-                            AppContext appContext = it.next();
+                        for (AppContext appContext : AppContext.getAppContexts()) {
                             if (appContext == showAppContext) {
                                 continue;
                             }
@@ -1073,6 +1073,7 @@ public class Dialog extends Window {
 
                     modalityPushed();
                     try {
+                        @SuppressWarnings("removal")
                         final EventQueue eventQueue = AccessController.doPrivileged(
                                 (PrivilegedAction<EventQueue>) Toolkit.getDefaultToolkit()::getSystemEventQueue);
                         secondaryLoop = eventQueue.createSecondaryLoop(() -> true, modalFilter, 0);
@@ -1086,9 +1087,7 @@ public class Dialog extends Window {
                     // if this dialog is toolkit-modal, its filter must be removed
                     // from all EDTs (for all AppContexts)
                     if (modalityType == ModalityType.TOOLKIT_MODAL) {
-                        Iterator<AppContext> it = AppContext.getAppContexts().iterator();
-                        while (it.hasNext()) {
-                            AppContext appContext = it.next();
+                        for (AppContext appContext : AppContext.getAppContexts()) {
                             if (appContext == showAppContext) {
                                 continue;
                             }
@@ -1589,6 +1588,7 @@ public class Dialog extends Window {
 
     private void checkModalityPermission(ModalityType mt) {
         if (mt == ModalityType.TOOLKIT_MODAL) {
+            @SuppressWarnings("removal")
             SecurityManager sm = System.getSecurityManager();
             if (sm != null) {
                 sm.checkPermission(AWTPermissions.TOOLKIT_MODALITY_PERMISSION);
@@ -1606,6 +1606,7 @@ public class Dialog extends Window {
      * @throws HeadlessException if {@code GraphicsEnvironment.isHeadless()}
      *         returns {@code true}
      */
+    @Serial
     private void readObject(ObjectInputStream s)
         throws ClassNotFoundException, IOException, HeadlessException
     {
@@ -1618,7 +1619,7 @@ public class Dialog extends Window {
 
         try {
             checkModalityPermission(localModalityType);
-        } catch (AccessControlException ace) {
+        } catch (@SuppressWarnings("removal") AccessControlException ace) {
             localModalityType = DEFAULT_MODALITY_TYPE;
         }
 
@@ -1672,9 +1673,10 @@ public class Dialog extends Window {
      */
     protected class AccessibleAWTDialog extends AccessibleAWTWindow
     {
-        /*
-         * JDK 1.3 serialVersionUID
+        /**
+         * Use serialVersionUID from JDK 1.3 for interoperability.
          */
+        @Serial
         private static final long serialVersionUID = 4837230331833941201L;
 
         /**
