@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -215,11 +215,11 @@ final class CompilerToVM {
      * constant pool cache first.
      *
      * The behavior of this method is undefined if {@code cpi} does not denote one of the following
-     * entry types: {@code JVM_CONSTANT_String}, {@code JVM_CONSTANT_MethodHandle},
-     * {@code JVM_CONSTANT_MethodHandleInError}, {@code JVM_CONSTANT_MethodType} and
-     * {@code JVM_CONSTANT_MethodTypeInError}.
+     * entry types: {@code JVM_CONSTANT_Dynamic}, {@code JVM_CONSTANT_String},
+     * {@code JVM_CONSTANT_MethodHandle}, {@code JVM_CONSTANT_MethodHandleInError},
+     * {@code JVM_CONSTANT_MethodType} and {@code JVM_CONSTANT_MethodTypeInError}.
      */
-    native HotSpotObjectConstantImpl resolvePossiblyCachedConstantInPool(HotSpotConstantPool constantPool, int cpi);
+    native JavaConstant resolvePossiblyCachedConstantInPool(HotSpotConstantPool constantPool, int cpi);
 
     /**
      * Gets the {@code JVM_CONSTANT_NameAndType} index from the entry at index {@code cpi} in
@@ -512,19 +512,6 @@ final class CompilerToVM {
      */
     native long getLocalVariableTableStart(HotSpotResolvedJavaMethodImpl method);
 
-    /**
-     * Reads an object pointer within a VM data structure. That is, any {@link VMField} whose
-     * {@link VMField#type type} is {@code "oop"} (e.g., {@code Klass::_java_mirror},
-     * {@code JavaThread::_threadObj}).
-     *
-     * Note that {@code Unsafe.getObject(Object, long)} cannot be used for this since it does a
-     * {@code narrowOop} read if the VM is using compressed oops whereas oops within VM data
-     * structures are (currently) always uncompressed.
-     *
-     * @param address address of an oop field within a VM data structure
-     */
-    native HotSpotObjectConstantImpl readUncompressedOop(long address);
-
     /**
      * Sets flags on {@code method} indicating that it should never be inlined or compiled by the
      * VM.
@@ -557,10 +544,10 @@ final class CompilerToVM {
     native int getCountersSize();
 
     /**
-     * Change the size of the counters allocated for JVMCI. This requires a safepoint to
+     * Attempt to change the size of the counters allocated for JVMCI. This requires a safepoint to
      * safely reallocate the storage but it's advisable to increase the size in reasonable chunks.
      */
-    native void setCountersSize(int newSize);
+    native boolean setCountersSize(int newSize);
 
     /**
      * Determines if {@code metaspaceMethodData} is mature.
@@ -601,8 +588,9 @@ final class CompilerToVM {
      * {@link HotSpotVMConfig#invalidVtableIndex} if {@code method} is not in {@code type}'s
      * v-table.
      *
-     * @throws InternalError if {@code type} is an interface or {@code method} is not held by an
-     *             interface or class represented by {@code type} is not initialized
+     * @throws InternalError if {@code type} is an interface, {@code method} is not defined by an
+     *             interface, {@code type} does not implement the interface defining {@code method}
+     *             or class represented by {@code type} is not initialized
      */
     native int getVtableIndexForInterfaceMethod(HotSpotResolvedObjectTypeImpl type, HotSpotResolvedJavaMethodImpl method);
 
@@ -612,18 +600,14 @@ final class CompilerToVM {
     native boolean shouldDebugNonSafepoints();
 
     /**
-     * Writes {@code length} bytes from {@code bytes} starting at offset {@code offset} to HotSpot's
-     * log stream.
+     * Writes {@code length} bytes from {@code buffer} to HotSpot's log stream.
      *
+     * @param buffer if {@code length <= 8}, then the bytes are encoded in this value in native
+     *            endianness order otherwise this is the address of a native memory buffer holding
+     *            the bytes
      * @param flush specifies if the log stream should be flushed after writing
-     * @param canThrow specifies if an error in the {@code bytes}, {@code offset} or {@code length}
-     *            arguments should result in an exception or a negative return value
-     * @return 0 on success, -1 if {@code bytes == null && !canThrow}, -2 if {@code !canThrow} and
-     *         copying would cause access of data outside array bounds
-     * @throws NullPointerException if {@code bytes == null}
-     * @throws IndexOutOfBoundsException if copying would cause access of data outside array bounds
      */
-    native int writeDebugOutput(byte[] bytes, int offset, int length, boolean flush, boolean canThrow);
+    native void writeDebugOutput(long buffer, int length, boolean flush);
 
     /**
      * Flush HotSpot's log stream.
@@ -739,18 +723,6 @@ final class CompilerToVM {
      */
     native Object getFlagValue(String name);
 
-    /**
-     * Gets the host class for {@code type}.
-     */
-    native HotSpotResolvedObjectTypeImpl getHostClass(HotSpotResolvedObjectTypeImpl type);
-
-    /**
-     * Gets the object at the address {@code oopAddress}.
-     *
-     * @param oopAddress a valid {@code oopDesc**} value
-     */
-    native Object getObjectAtAddress(long oopAddress);
-
     /**
      * @see ResolvedJavaType#getInterfaces()
      */
@@ -762,7 +734,7 @@ final class CompilerToVM {
     native HotSpotResolvedJavaType getComponentType(HotSpotResolvedObjectTypeImpl type);
 
     /**
-     * Get the array class for {@code type}. This can't be done symbolically since anonymous types
+     * Get the array class for {@code type}. This can't be done symbolically since hidden classes
      * can't be looked up by name.
      */
     native HotSpotResolvedObjectTypeImpl getArrayType(HotSpotResolvedJavaType type);
@@ -772,6 +744,11 @@ final class CompilerToVM {
      */
     native void ensureInitialized(HotSpotResolvedObjectTypeImpl type);
 
+    /**
+     * Forces linking of {@code type}.
+     */
+    native void ensureLinked(HotSpotResolvedObjectTypeImpl type);
+
     /**
      * Checks if {@code object} is a String and is an interned string value.
      */
@@ -805,14 +782,22 @@ final class CompilerToVM {
     native ResolvedJavaMethod[] getDeclaredMethods(HotSpotResolvedObjectTypeImpl holder);
 
     /**
-     * Reads the current value of a static field.
+     * Reads the current value of a static field. If {@code expectedType} is non-null, then the
+     * object is expected to be a subtype of {@code expectedType} and extra sanity checking is
+     * performed on the offset and kind of the read being performed.
+     *
+     * @throws IllegalArgumentException if any of the sanity checks fail
      */
-    native JavaConstant readFieldValue(HotSpotResolvedObjectTypeImpl resolvedObjectType, HotSpotResolvedJavaField field, boolean isVolatile);
+    native JavaConstant readFieldValue(HotSpotResolvedObjectTypeImpl object, HotSpotResolvedObjectTypeImpl expectedType, long offset, JavaKind kind);
 
     /**
-     * Reads the current value of an instance field.
+     * Reads the current value of an instance field. If {@code expectedType} is non-null, then the
+     * object is expected to be a subtype of {@code expectedType} and extra sanity checking is
+     * performed on the offset and kind of the read being performed.
+     *
+     * @throws IllegalArgumentException if any of the sanity checks fail
      */
-    native JavaConstant readFieldValue(HotSpotObjectConstantImpl object, HotSpotResolvedJavaField field, boolean isVolatile);
+    native JavaConstant readFieldValue(HotSpotObjectConstantImpl object, HotSpotResolvedObjectTypeImpl expectedType, long offset, JavaKind kind);
 
     /**
      * @see ResolvedJavaType#isInstance(JavaConstant)
@@ -856,31 +841,6 @@ final class CompilerToVM {
      */
     native Object readArrayElement(HotSpotObjectConstantImpl object, int index);
 
-    /**
-     * Reads a byte sized value from {@code displacement} in {@code object}.
-     */
-    native byte getByte(HotSpotObjectConstantImpl object, long displacement);
-
-    /**
-     * Reads a short sized value from {@code displacement} in {@code object}.
-     */
-    native short getShort(HotSpotObjectConstantImpl object, long displacement);
-
-    /**
-     * Reads an int sized value from {@code displacement} in {@code object}.
-     */
-    native int getInt(HotSpotObjectConstantImpl object, long displacement);
-
-    /**
-     * Reads a long sized value from {@code displacement} in {@code object}.
-     */
-    native long getLong(HotSpotObjectConstantImpl object, long displacement);
-
-    /**
-     * Reads a Java object from {@code displacement} in {@code object}.
-     */
-    native HotSpotObjectConstantImpl getObject(HotSpotObjectConstantImpl object, long displacement);
-
     /**
      * @see HotSpotJVMCIRuntime#registerNativeMethods
      */
@@ -889,7 +849,7 @@ final class CompilerToVM {
     /**
      * @see HotSpotJVMCIRuntime#translate(Object)
      */
-    native long translate(Object obj);
+    native long translate(Object obj, boolean callPostTranslation);
 
     /**
      * @see HotSpotJVMCIRuntime#unhand(Class, long)
@@ -972,9 +932,10 @@ final class CompilerToVM {
     native long getCurrentJavaThread();
 
     /**
+     * @param name name of current thread if in a native image otherwise {@code null}
      * @see HotSpotJVMCIRuntime#attachCurrentThread
      */
-    native boolean attachCurrentThread(boolean asDaemon);
+    native boolean attachCurrentThread(byte[] name, boolean asDaemon);
 
     /**
      * @see HotSpotJVMCIRuntime#detachCurrentThread()
@@ -985,4 +946,47 @@ final class CompilerToVM {
      * @see HotSpotJVMCIRuntime#exitHotSpot(int)
      */
     native void callSystemExit(int status);
+
+    /**
+     * @see JFR.Ticks#now
+     */
+    native long ticksNow();
+
+    /**
+     * @see HotSpotJVMCIRuntime#setThreadLocalObject(int, Object)
+     */
+    native void setThreadLocalObject(int id, Object value);
+
+    /**
+     * @see HotSpotJVMCIRuntime#getThreadLocalObject(int)
+     */
+    native Object getThreadLocalObject(int id);
+
+    /**
+     * @see HotSpotJVMCIRuntime#setThreadLocalLong(int, long)
+     */
+    native void setThreadLocalLong(int id, long value);
+
+    /**
+     * @see HotSpotJVMCIRuntime#getThreadLocalLong(int)
+     */
+    native long getThreadLocalLong(int id);
+
+    /**
+     * Adds phases in HotSpot JFR.
+     *
+     * @see JFR.CompilerPhaseEvent#write
+     */
+    native int registerCompilerPhase(String phaseName);
+
+    /**
+     * @see JFR.CompilerPhaseEvent#write
+     */
+    native void notifyCompilerPhaseEvent(long startTime, int phase, int compileId, int level);
+
+    /**
+     * @see JFR.CompilerInliningEvent#write
+     */
+    native void notifyCompilerInliningEvent(int compileId, HotSpotResolvedJavaMethodImpl caller, HotSpotResolvedJavaMethodImpl callee, boolean succeeded, String message, int bci);
+
 }
