@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -154,6 +150,16 @@ public class FormatData_mn extends ListResourceBundle {
         final String[] metaValue_AmPmMarkers = new String[] {
                "\u04af.\u04e9.",
                "\u04af.\u0445.",
+               "\u0448\u04e9\u043d\u04e9 \u0434\u0443\u043d\u0434",
+               "\u04af\u0434 \u0434\u0443\u043d\u0434",
+               "\u04e9\u0433\u043b\u04e9\u04e9",
+               "",
+               "\u04e9\u0434\u04e9\u0440",
+               "",
+               "\u043e\u0440\u043e\u0439",
+               "",
+               "\u0448\u04e9\u043d\u04e9",
+               "",
             };
         final String[] metaValue_Eras = new String[] {
                "\u041c\u042d\u04e8",
@@ -229,6 +235,8 @@ public class FormatData_mn extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -247,15 +255,9 @@ public class FormatData_mn extends ListResourceBundle {
             { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayAbbreviations },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4\u00a0#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0438\u0441\u043b\u0430\u043c\u044b\u043d \u0446\u0430\u0433\u043b\u0430\u0432\u0430\u0440" },
+            { "DayPeriodRules", "midnight:00:00;noon:12:00;night1:21:00-06:00;afternoon1:12:00-18:00;morning1:06:00-12:00;evening1:18:00-21:00" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -265,18 +267,18 @@ public class FormatData_mn extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u043c\u044f\u043d\u0433\u0430",
-                    "00 \u043c\u044f\u043d\u0433\u0430",
-                    "000 \u043c\u044f\u043d\u0433\u0430",
-                    "0 \u0441\u0430\u044f",
-                    "00 \u0441\u0430\u044f",
-                    "000 \u0441\u0430\u044f",
-                    "0 \u0442\u044d\u0440\u0431\u0443\u043c",
-                    "00 \u0442\u044d\u0440\u0431\u0443\u043c",
-                    "000 \u0442\u044d\u0440\u0431\u0443\u043c",
-                    "0 \u0438\u0445 \u043d\u0430\u044f\u0434",
-                    "00 \u0438\u0445 \u043d\u0430\u044f\u0434",
-                    "000 \u0438\u0445 \u043d\u0430\u044f\u0434",
+                    "{one:0' '\u043c\u044f\u043d\u0433\u0430 other:0' '\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:00' '\u043c\u044f\u043d\u0433\u0430 other:00' '\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:000' '\u043c\u044f\u043d\u0433\u0430 other:000' '\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:0' '\u0441\u0430\u044f other:0' '\u0441\u0430\u044f}",
+                    "{one:00' '\u0441\u0430\u044f other:00' '\u0441\u0430\u044f}",
+                    "{one:000' '\u0441\u0430\u044f other:000' '\u0441\u0430\u044f}",
+                    "{one:0' '\u0442\u044d\u0440\u0431\u0443\u043c other:0' '\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:00' '\u0442\u044d\u0440\u0431\u0443\u043c other:00' '\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:000' '\u0442\u044d\u0440\u0431\u0443\u043c other:000' '\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:0' '\u0438\u0445' '\u043d\u0430\u044f\u0434 other:0' '\u0438\u0445' '\u043d\u0430\u044f\u0434}",
+                    "{one:00' '\u0438\u0445' '\u043d\u0430\u044f\u0434 other:00' '\u0438\u0445' '\u043d\u0430\u044f\u0434}",
+                    "{one:000' '\u0438\u0445' '\u043d\u0430\u044f\u0434 other:000' '\u0438\u0445' '\u043d\u0430\u044f\u0434}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -323,26 +325,26 @@ public class FormatData_mn extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u043c\u044f\u043d\u0433\u0430",
-                    "00\u00a0\u043c\u044f\u043d\u0433\u0430",
-                    "000\u00a0\u043c\u044f\u043d\u0433\u0430",
-                    "0\u00a0\u0441\u0430\u044f",
-                    "00\u00a0\u0441\u0430\u044f",
-                    "000\u00a0\u0441\u0430\u044f",
-                    "0\u00a0\u0442\u044d\u0440\u0431\u0443\u043c",
-                    "00\u00a0\u0442\u044d\u0440\u0431\u0443\u043c",
-                    "000\u0422",
-                    "0\u0418\u041d",
-                    "00\u0418\u041d",
-                    "000\u0418\u041d",
+                    "{one:0\u00a0\u043c\u044f\u043d\u0433\u0430 other:0\u00a0\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:00\u00a0\u043c\u044f\u043d\u0433\u0430 other:00\u00a0\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:000\u00a0\u043c\u044f\u043d\u0433\u0430 other:000\u00a0\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:0\u00a0\u0441\u0430\u044f other:0\u00a0\u0441\u0430\u044f}",
+                    "{one:00\u00a0\u0441\u0430\u044f other:00\u00a0\u0441\u0430\u044f}",
+                    "{one:000\u00a0\u0441\u0430\u044f other:000\u00a0\u0441\u0430\u044f}",
+                    "{one:0\u00a0\u0442\u044d\u0440\u0431\u0443\u043c other:0\u00a0\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:00\u00a0\u0442\u044d\u0440\u0431\u0443\u043c other:00\u00a0\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:000\u0422 other:000\u0422}",
+                    "{one:0\u0418\u041d other:0\u0418\u041d}",
+                    "{one:00\u0418\u041d other:00\u0418\u041d}",
+                    "{one:000\u0418\u041d other:000\u0418\u041d}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "{0}-\u043d \u0437\u0443\u043d\u044b \u0446\u0430\u0433" },
             { "DatePatterns",
                 new String[] {
-                    "y.MM.dd, EEEE",
-                    "y.MM.dd",
+                    "y '\u043e\u043d\u044b' MMMM'\u044b\u043d' d, EEEE '\u0433\u0430\u0440\u0430\u0433'",
+                    "y '\u043e\u043d\u044b' MMMM'\u044b\u043d' d",
                     "y '\u043e\u043d\u044b' MMM'\u044b\u043d' d",
                     "y.MM.dd",
                 }
@@ -361,6 +363,7 @@ public class FormatData_mn extends ListResourceBundle {
                     "\u0411\u044f\u043c\u0431\u0430",
                 }
             },
+            { "PluralRules", "one:n = 1" },
             { "field.hour", "\u0446\u0430\u0433" },
             { "calendarname.buddhist", "\u0431\u0443\u0434\u0434\u044b\u043d \u0446\u0430\u0433\u043b\u0430\u0432\u0430\u0440" },
             { "standalone.MonthNames",
@@ -380,6 +383,14 @@ public class FormatData_mn extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4\u00a0#,##0.00",
+                    "#,##0%",
+                    "\u00a4\u00a0#,##0.00",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayAbbreviations },
             { "japanese.DayNarrows", metaValue_DayAbbreviations },
             { "QuarterNames", metaValue_QuarterNames },
