@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -154,6 +150,20 @@ public class FormatData_pt extends ListResourceBundle {
                "T3",
                "T4",
             };
+        final String[] metaValue_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+               "meia-noite",
+               "meio-dia",
+               "da manh\u00e3",
+               "",
+               "da tarde",
+               "",
+               "da noite",
+               "",
+               "da madrugada",
+               "",
+            };
         final String[] metaValue_Eras = new String[] {
                "a.C.",
                "d.C.",
@@ -170,10 +180,6 @@ public class FormatData_pt extends ListResourceBundle {
                "3",
                "4",
             };
-        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "EB",
@@ -203,8 +209,9 @@ public class FormatData_pt extends ListResourceBundle {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "ano" },
             { "calendarname.islamic-umalqura", "Calend\u00e1rio Isl\u00e2mico (Umm al-Qura)" },
-            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns",
                 new String[] {
                     "EEEE, d 'de' MMMM 'de' y G",
@@ -217,11 +224,13 @@ public class FormatData_pt extends ListResourceBundle {
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "Calend\u00e1rio Civil Isl\u00e2mico" },
-            { "islamic.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.regionFormat.standard", "Hor\u00e1rio Padr\u00e3o: {0}" },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.japanese", "Calend\u00e1rio Japon\u00eas" },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
@@ -244,6 +253,7 @@ public class FormatData_pt extends ListResourceBundle {
                     "{1} {0}",
                 }
             },
+            { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -273,7 +283,7 @@ public class FormatData_pt extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "minuto" },
             { "field.era", "era" },
-            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
@@ -288,8 +298,9 @@ public class FormatData_pt extends ListResourceBundle {
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Calend\u00e1rio Isl\u00e2mico" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "DayPeriodRules", "midnight:00:00;noon:12:00;night1:00:00-06:00;afternoon1:12:00-19:00;morning1:06:00-12:00;evening1:19:00-24:00" },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
-            { "japanese.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "Hor\u00e1rio {0}" },
@@ -312,15 +323,15 @@ public class FormatData_pt extends ListResourceBundle {
                     "{one:000' 'trilh\u00e3o other:000' 'trilh\u00f5es}",
                 }
             },
+            { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
-            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
@@ -328,10 +339,12 @@ public class FormatData_pt extends ListResourceBundle {
             { "field.zone", "fuso hor\u00e1rio" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
-            { "buddhist.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "dia da semana" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -350,7 +363,7 @@ public class FormatData_pt extends ListResourceBundle {
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -387,6 +400,7 @@ public class FormatData_pt extends ListResourceBundle {
             { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
+            { "PluralRules", "one:i = 0..1" },
             { "field.hour", "hora" },
             { "calendarname.buddhist", "Calend\u00e1rio Budista" },
             { "standalone.MonthNames", metaValue_MonthNames },
@@ -403,6 +417,7 @@ public class FormatData_pt extends ListResourceBundle {
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
